/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.mvn.reports;

import ch.hortis.sonar.mvn.Report;
import org.apache.maven.model.Plugin;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;
import org.sonar.plugins.maven.MavenUtils;

import java.io.File;
import java.util.Arrays;
import java.util.List;

public class CloverHandler extends ReportHandler {

  public void configurePlugin(MavenProject pom, Plugin plugin) {
    unsetConfigParameter( plugin, "outputDirectory" );
    setConfigParameter( plugin, "generateHistorical", "false" );
    setConfigParameter( plugin, "generateXml", "true" );
    setConfigParameter( plugin, "generatePdf", "false" );
    setConfigParameter( plugin, "generateHtml", "false" );
    String javaVersion = MavenUtils.getJavaVersion(pom);
    if (MavenUtils.getConfigurationValue(plugin, "licenseLocation") == null) {
      File cloverLicense = getCloverLicense(pom);
      if (cloverLicense.exists()) {
        setConfigParameter( plugin, "licenseLocation", cloverLicense.getPath() );
      }
    }

    if (javaVersion != null) {
      setConfigParameter(plugin, "jdk", javaVersion);
    }
  }
  
  public boolean execute(MavenProject pom, Log log) {
    return isLicenceProvided(pom);
  }
  
  public static boolean isLicenceProvided(MavenProject pom) {
    Plugin plugin = Report.Clover.getReportHandler().createPluginWithConfiguration(pom);
    String licenseLocation = MavenUtils.getConfigurationValue(plugin, "licenseLocation");
    File license;
    if ( licenseLocation != null ) {
      license = new File( licenseLocation );
    } else {
      license = getCloverLicense(pom);
    }
    return license != null && license.exists();
  }
  
  public static File getCloverLicense(MavenProject pom) {
    return new File(pom.getBasedir(), "clover.license");
  }

  public List<String> getGoals() {
    return Arrays.asList("instrument","clover");
  }

  public boolean mustFailOnError() {
    return false;
  }

  public boolean executeEvenIfNoJavaSources() {
    return false;
  }

  public boolean executeEvenIfNoJavaTests() {
    return false;
  }
}
